# {{ project }}

{{ description }}

## Start

```cmd
python -m venv venv
venv\Scripts\activate.bat (cmd.exe)
venv\Scripts\Activate.ps1 (PowerShell)
source venv/bin/activate (bash/zsh)
pip install -r requirements.txt
python -m {{ package }}
...
deactivate
```
